==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/ExtensionsV1beta1DeploymentRollbackFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import java.util.Map;

public interface ExtensionsV1beta1DeploymentRollbackFluent<A extends ExtensionsV1beta1DeploymentRollbackFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    
/**
 * This method has been deprecated, please use method buildRollbackTo instead.
 * @return The buildable object.
 */
@Deprecated public ExtensionsV1beta1RollbackConfig getRollbackTo();
    public ExtensionsV1beta1RollbackConfig buildRollbackTo();
    public A withRollbackTo(ExtensionsV1beta1RollbackConfig rollbackTo);
    public Boolean hasRollbackTo();
    public ExtensionsV1beta1DeploymentRollbackFluent.RollbackToNested<A> withNewRollbackTo();
    public ExtensionsV1beta1DeploymentRollbackFluent.RollbackToNested<A> withNewRollbackToLike(ExtensionsV1beta1RollbackConfig item);
    public ExtensionsV1beta1DeploymentRollbackFluent.RollbackToNested<A> editRollbackTo();
    public ExtensionsV1beta1DeploymentRollbackFluent.RollbackToNested<A> editOrNewRollbackTo();
    public ExtensionsV1beta1DeploymentRollbackFluent.RollbackToNested<A> editOrNewRollbackToLike(ExtensionsV1beta1RollbackConfig item);
    public A addToUpdatedAnnotations(String key,String value);
    public A addToUpdatedAnnotations(Map<String,String> map);
    public A removeFromUpdatedAnnotations(String key);
    public A removeFromUpdatedAnnotations(Map<String,String> map);
    public Map<String,String> getUpdatedAnnotations();
    public A withUpdatedAnnotations(Map<String,String> updatedAnnotations);
    public Boolean hasUpdatedAnnotations();

    public interface RollbackToNested<N> extends io.kubernetes.client.fluent.Nested<N>,ExtensionsV1beta1RollbackConfigFluent<ExtensionsV1beta1DeploymentRollbackFluent.RollbackToNested<N>>{

        
    public N and();    public N endRollbackTo();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/ExtensionsV1beta1DeploymentRollbackFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;
import java.util.Map;

public interface ExtensionsV1beta1DeploymentRollbackFluent<A extends ExtensionsV1beta1DeploymentRollbackFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildRollbackTo instead.
 * @return The buildable object.
 */
@Deprecated public ExtensionsV1beta1RollbackConfig getRollbackTo();
    public ExtensionsV1beta1RollbackConfig buildRollbackTo();
    public A withRollbackTo(ExtensionsV1beta1RollbackConfig rollbackTo);
    public Boolean hasRollbackTo();
    public ExtensionsV1beta1DeploymentRollbackFluent.RollbackToNested<A> withNewRollbackTo();
    public ExtensionsV1beta1DeploymentRollbackFluent.RollbackToNested<A> withNewRollbackToLike(ExtensionsV1beta1RollbackConfig item);
    public ExtensionsV1beta1DeploymentRollbackFluent.RollbackToNested<A> editRollbackTo();
    public ExtensionsV1beta1DeploymentRollbackFluent.RollbackToNested<A> editOrNewRollbackTo();
    public ExtensionsV1beta1DeploymentRollbackFluent.RollbackToNested<A> editOrNewRollbackToLike(ExtensionsV1beta1RollbackConfig item);
    public A addToUpdatedAnnotations(String key,String value);
    public A addToUpdatedAnnotations(Map<String,String> map);
    public A removeFromUpdatedAnnotations(String key);
    public A removeFromUpdatedAnnotations(Map<String,String> map);
    public Map<String,String> getUpdatedAnnotations();
    public A withUpdatedAnnotations(Map<String,String> updatedAnnotations);
    public Boolean hasUpdatedAnnotations();

    public interface RollbackToNested<N> extends io.kubernetes.client.fluent.Nested<N>,ExtensionsV1beta1RollbackConfigFluent<ExtensionsV1beta1DeploymentRollbackFluent.RollbackToNested<N>>{

        
    public N and();    public N endRollbackTo();
}


}
